==> shakenfist-0.4.19-py3-none-any.whl: shakenfist/external_api/upload.py <==
import flask
from flask_jwt_extended import get_jwt_identity
from flask_jwt_extended import jwt_required
import os
import requests
import uuid

from shakenfist.daemons import daemon
from shakenfist.external_api import base as api_base
from shakenfist.config import config
from shakenfist import logutil
from shakenfist.upload import Upload
from shakenfist.util import general as util_general


LOG, HANDLER = logutil.setup(__name__)
daemon.set_log_level(LOG, 'api')


class UploadCreateEndpoint(api_base.Resource):
    @jwt_required
    def post(self):
        return Upload.new(str(uuid.uuid4()), config.NODE_NAME).external_view()


class UploadDataEndpoint(api_base.Resource):
    @jwt_required
    def post(self, upload_uuid=None):
        u = Upload.from_db(upload_uuid)
        if not u:
            return api_base.error(404, 'upload not found')

        if u.node != config.NODE_NAME:
            url = 'http://%s:%d%s' % (u.node, config.API_PORT,
                                      flask.request.environ['PATH_INFO'])
            api_token = util_general.get_api_token(
                'http://%s:%d' % (u.node, config.API_PORT),
                namespace=get_jwt_identity())
            r = requests.request(
                flask.request.environ['REQUEST_METHOD'], url,
                data=flask.request.get_data(cache=False, as_text=False,
                                            parse_form_data=False),
                headers={'Authorization': api_token,
                         'User-Agent': util_general.get_user_agent()})

            LOG.info('Proxied %s %s returns: %d, %s' % (
                     flask.request.environ['REQUEST_METHOD'], url,
                     r.status_code, r.text))
            resp = flask.Response(r.text,  mimetype='application/json')
            resp.status_code = r.status_code
            return resp

        upload_dir = os.path.join(config.STORAGE_PATH, 'uploads')
        os.makedirs(upload_dir, exist_ok=True)

        upload_path = os.path.join(upload_dir, u.uuid)
        with open(upload_path, 'ab') as f:
            f.write(flask.request.get_data(cache=False, as_text=False,
                                           parse_form_data=False))

        st = os.stat(upload_path)
        return st.st_size

==> shakenfist-0.4.20.0rc5-py3-none-any.whl: shakenfist/external_api/upload.py <==
import flask
from flask_jwt_extended import jwt_required
import os
import uuid

from shakenfist.daemons import daemon
from shakenfist.external_api import base as api_base
from shakenfist.config import config
from shakenfist import logutil
from shakenfist.upload import Upload


LOG, HANDLER = logutil.setup(__name__)
daemon.set_log_level(LOG, 'api')


class UploadCreateEndpoint(api_base.Resource):
    @jwt_required
    def post(self):
        return Upload.new(str(uuid.uuid4()), config.NODE_NAME).external_view()


class UploadDataEndpoint(api_base.Resource):
    @jwt_required
    @api_base.arg_is_upload_uuid
    @api_base.redirect_upload_request
    def post(self, upload_uuid=None, upload_from_db=None):
        upload_dir = os.path.join(config.STORAGE_PATH, 'uploads')
        os.makedirs(upload_dir, exist_ok=True)

        upload_path = os.path.join(upload_dir, upload_from_db.uuid)
        with open(upload_path, 'ab') as f:
            f.write(flask.request.get_data(cache=False, as_text=False,
                                           parse_form_data=False))

        st = os.stat(upload_path)
        return st.st_size


class UploadTruncateEndpoint(api_base.Resource):
    @jwt_required
    @api_base.arg_is_upload_uuid
    @api_base.redirect_upload_request
    def post(self, upload_uuid=None, offset=None, upload_from_db=None):
        upload_dir = os.path.join(config.STORAGE_PATH, 'uploads')
        os.makedirs(upload_dir, exist_ok=True)

        upload_path = os.path.join(upload_dir, upload_from_db.uuid)
        os.truncate(upload_path, int(offset))
